@@ -39,7 +39,3 @@ hdlr.setFormatter(formatter)
 logger.addHandler(hdlr)
 logger.setLevel(logging.DEBUG)
 
-def hard_debug(self, msg):
-    self.debug(80*'\n'+msg+80*'\n')
-
-setattr(logger, 'hard_debug', hard_debug)
