@@ -80,8 +80,8 @@ class ClassVar(object):
         self.value = var
         self.cls = cls
 
-    def __call__(self, var):
-        return ClassVarVar(self.value, self.cls, var)
+    def __call__(self, var='', **kwargs):
+        return ClassVarVar(self.value, self.cls, var, **kwargs)
 
     def get_constraint(self, vrs, ancestor, mod_path):
         ci = utils.clips_instance(ancestor, mod_path)
@@ -94,6 +94,20 @@ class ClassVar(object):
                                     'ci': ci,
                                     'cls': self.cls.__name__}
 
+    def get_slot_constraint(self, vrs):
+        """
+        build rule CE constraint for clips
+        for a slot constraint for a pred in a prop in a rule
+        """
+        if self.value in vrs:
+            return self.cls(self.value).get_var_slot_constraint(vrs, self.value)
+        else:
+            vrs[self.value] = ()
+            return '''?%(cvar)s&:(or (eq ?%(cvar)s %(cls)s)
+                                  subclassp ?%(cvar)s %(cls)s)''' % {
+                                    'cvar': self.value,
+                                    'cls': self.cls.__name__}
+
     def get_isc(self, templs, queries, vrs):
         """
         get instance-set condition;
@@ -111,20 +125,6 @@ class ClassVar(object):
         vrs[self.value] = ()
         return '?%s' % self.value
 
-    def get_slot_constraint(self, vrs):
-        """
-        build rule CE constraint for clips
-        for a slot constraint for a pred in a prop in a rule
-        """
-        if self.value in vrs:
-            return self.cls(self.value).get_var_slot_constraint(vrs, self.value)
-        else:
-            vrs[self.value] = ()
-            return '''%(cvar)s&:(or (eq %(cvar)s %(cls)s)
-                                  subclassp %(cvar)s %(cls)s)''' % {
-                                    'cvar': self.value,
-                                    'cls': self.cls.__name__}
-
     def put(self, vrs):
         return self.cls(self.value).put(vrs)
 
@@ -132,18 +132,20 @@ class ClassVar(object):
 class ClassVarVar(object):
     '''
     '''
-    def __init__(self, clsvar, cls, var):
+    def __init__(self, clsvar, cls, var, **kwargs):
         self.value = var
         self.clsvar = clsvar
         self.cls = cls
+        self.ob = cls(var, **kwargs)
 
     def get_constraint(self, vrs, ancestor, mod_path):
         ci = utils.clips_instance(ancestor, mod_path)
         constraint = []
-        if self.value in vrs:
-            return self.cls(self.value).get_constraint(vrs, ancestor, mod_path)
+        if not self.value or self.value in vrs:
+            return self.ob.get_constraint(vrs, ancestor, mod_path)
         else:
             vrs[self.value] = (ancestor, mod_path)
+            vrs[self.clsvar] = (ancestor, mod_path, ['class'])
             return '''&:(or
                           (eq (class %(ci)s) %(cls)s)
                           (subclassp (class %(ci)s) %(cls)s))''' % {
@@ -155,10 +157,11 @@ class ClassVarVar(object):
         build rule CE constraint for clips
         for a slot constraint for a pred in a prop in a rule
         """
-        if self.value in vrs:
-            return self.cls(self.value).get_var_slot_constraint(vrs, self.value)
+        if not self.value or self.value in vrs:
+            return self.ob.get_var_slot_constraint(vrs, self.value)
         else:
             vrs[self.value] = ()
+            vrs[self.clsvar] = (self.value, [], ['class'])
             return '''?%(var)s&:(or
                                  (eq (class ?%(var)s) %(cls)s)
                                  (subclassp (class ?%(var)s) %(cls)s))''' % {
@@ -166,7 +169,7 @@ class ClassVarVar(object):
                                     'cls': self.cls.__name__}
 
     def put(self, vrs):
-        return self.cls(self.value).put(vrs)
+        return self.ob.put(vrs)
 
     def get_isc(self, templs, queries, vrs):
         """
@@ -177,6 +180,9 @@ class ClassVarVar(object):
             templs.append((self.value, self.clsvar))
             queries.append('(eq ?%s %s)' % (self.value,
                                  utils.clips_instance(*(vrs[self.value]))))
+        try:
+            self.ob.get_mod_isc(self.value, templs, queries, vrs)
+        except AttributeError: pass
         vrs[self.value] = ()
         return '?%s' % self.value
 
