@@ -18,28 +18,13 @@
 
 import clips
 from nl.log import logger
-from nl.clps import class_constraint
-from nl.utils import register, varpat, Name, clips_instance, get_class, _newvar
+from nl import utils
+from nl.metanl import Noun, Namable
 
-
-class MetaThing(type):
-    """
-    When Name is extended, this adds 1 defclass to clips
-    creating a subclass of Name.
-    And registers the class in subclasses
-    """
-    def __init__(cls, classname, bases, newdict):
-        super(MetaThing, cls).__init__(classname, bases, newdict)
-        clp = '(defclass %s (is-a %s))' % (classname, bases[0].__name__)
-        logger.info(clp)
-        clips.Build(clp)
-        cls._v_clips_class = clips.FindClass(classname)
-        register(classname, cls)
-
-class Thing(Name):
+class Thing(Namable):
     """
     """
-    __metaclass__ = MetaThing
+    __metaclass__ = Noun
 
     def __init__(self, value):
         if value.startswith('['):
@@ -59,14 +44,14 @@ class Thing(Name):
         if not isinstance(instance, clips._clips_wrap.Instance):
             instance = clips.FindInstance(instance)
         clsname = str(instance.Class.Name)
-        cls = get_class(clsname)
+        cls = utils.get_class(clsname)
         return cls(str(instance))
 
     def get_ce(self, vrs):
         """
         build CE for clips
         """
-        if varpat.match(self.value):
+        if utils.varpat.match(self.value):
             vrs[self.value] = ()
             ce = '(logical (object (is-a %s) (name ?%s)))'
             return ce % (self.__class__.__name__, self.value)
@@ -77,13 +62,13 @@ class Thing(Name):
         build rule CE constraint for clips
         for a slot constraint for a pred in a prop in a rule
         """
-        if varpat.match(self.value):
+        if utils.varpat.match(self.value):
             return self.get_var_slot_constraint(vrs, self.value)
         return '[%s]' % self.value
 
     def get_constraint(self, vrs, ancestor, mod_path):
-        ci = clips_instance(ancestor, mod_path)
-        if varpat.match(self.value):
+        ci = utils.clips_instance(ancestor, mod_path)
+        if utils.varpat.match(self.value):
             constraint = self.get_var_constraint(vrs, ancestor, mod_path, ci)
         else:
             constraint = '&:(eq %s [%s])' % (ci, self.value)
@@ -94,13 +79,12 @@ class Thing(Name):
         get instance-set condition;
         return (instance-set templates, instance-set queries)
         """
-        if varpat.match(self.value):
+        if utils.varpat.match(self.value):
             if self.value in vrs and vrs[self.value]:
-                newvar = _newvar()
-                templs.append((newvar, self.__class__.__name__))
-                queries.append('(eq ?%s %s)' % (newvar,
-                                     clips_instance(*(vrs[self.value]))))
-                return '?%s' % newvar
+                newvar = self.value
+                templs.append((self.value, self.__class__.__name__))
+                queries.append('(eq ?%s %s)' % (self.value,
+                                     utils.clips_instance(*(vrs[self.value]))))
             vrs[self.value] = ()
             return '?%s' % self.value
         else:
@@ -111,7 +95,7 @@ class Thing(Name):
         get instance-set method;
         return (instance-set templates, instance-set queries)
         """
-        if varpat.match(self.value):
+        if utils.varpat.match(self.value):
             templs.append((self.value, self.__class__.__name__))
             vrs[self.value] = ()
         else:
@@ -119,7 +103,7 @@ class Thing(Name):
             queries.append('(eq ?%s [%s])' % (newvar, self.value))
 
     def put(self, vrs):
-        if varpat.match(self.value):
+        if utils.varpat.match(self.value):
             return self.put_var(vrs)
         else:
             return '[%s]' % self.value
@@ -132,6 +116,3 @@ class Thing(Name):
             vrs = {}
         val = self.put(vrs)
         return '(reduce-class %s %s)' % (val, self.__class__.__name__)
-
-
-register('Thing', Thing)
