@@ -15,15 +15,15 @@
 #
 # You should have received a copy of the GNU Lesser General Public License
 # along with ln.  If not, see <http://www.gnu.org/licenses/>.
-from datetime import datetime
+
 import clips
-from nl.clps import class_constraint
+from nl.log import logger
 from nl import utils
-from nl.arith import Number
+from nl.metanl import Namable, Number
 
 _m = []
 
-class Time(utils.Name):
+class Time(Namable):
     """
     abstract ancestor for Instant & Duration
     """
@@ -37,7 +37,6 @@ class Time(utils.Name):
                 instance = clips.FindInstance(instance)
         return Duration.from_clips(instance)
 
-utils.register('Time', Time)
 
 class Instant(Time, Number):
     '''
@@ -80,7 +79,6 @@ class Instant(Time, Number):
             ''' % {'parent': parent, 'self': num} )
         return num
 
-utils.register('Instant', Instant)
 
 class Duration(Time):
 
@@ -138,11 +136,10 @@ class Duration(Time):
         build rule CE slot constraint for clips
         as time in a prem
         """
-        newvar = utils._newvar()
         if utils.varpat.match(self.value):
             return self.get_var_slot_constraint(vrs, self.value)
-        core = '(eq (send %s get-start) %s)' % (newvar, self.start.get_slot_constraint(vrs))
-        return '?%(var)s&:(and %(core)s (eq (send %(var)s get-end) %(end)s))' % {'core': core, 'var': newvar, 'end': self.end.get_slot_constraint(vrs)}
+        core = '(eq (send %s get-start) %s)' % (self.value, self.start.get_slot_constraint(vrs))
+        return '?%(var)s&:(and %(core)s (eq (send %(var)s get-end) %(end)s))' % {'core': core, 'var': self.value, 'end': self.end.get_slot_constraint(vrs)}
 
     def put(self, vrs):
         if utils.varpat.match(self.value):
@@ -159,28 +156,22 @@ class Duration(Time):
         get instance-set condition;
         modify (instance-set templates, instance-set queries)
         """
-        newvar = utils._newvar()
         if utils.varpat.match(self.value):
             if self.value in vrs:
                 if vrs[self.value]:
-                    queries.append('(eq ?%s %s)' % (newvar,
+                    queries.append('(eq ?%s %s)' % (self.value,
                                      utils.clips_instance(*(vrs[self.value]))))
-                else:
-                    newvar = self.value
-            else:
-                vrs[self.value] = ()
-                newvar = self.value
-            templs.append((newvar, 'Duration'))
-            return '?%s' % newvar
+            vrs[self.value] = ()
+            templs.append((self.value, 'Duration'))
+            return '?%s' % self.value
         start = getattr(self, 'start', _m)
         if parent:
-            newvar = '%s:time' % parent
             core_start = '(send ?%s:time get-start)' % parent
             core_end = '(send ?%s:time get-end)' % parent
         else:
-            templs.append((newvar, 'Duration'))
-            core_start = '?%s:start' % newvar
-            core_end = '?%s:end' % newvar
+            templs.append((self.value, 'Duration'))
+            core_start = '?%s:start' % self.value
+            core_end = '?%s:end' % self.value
         if start is not _m and \
            not (utils.varpat.match(start.value) and \
            start.value not in vrs):
@@ -192,7 +183,7 @@ class Duration(Time):
            end.value not in vrs):
             queries.append('(= %s %s)' % (core_end,
                                   end.get_isc(templs, queries, vrs)))
-        return '?%s' % newvar
+        return '?%s' % self.value
 
     def get_ism(self,  templs, queries, vrs, newvar='time'):
         """
@@ -206,9 +197,8 @@ class Duration(Time):
             templs.append((newvar, self.__class__.__name__))
             queries.append('(eq ?%s %s)' % (newvar, self.put(vrs)))
 
-utils.register('Duration', Duration)
 
-class Finish(utils.Name):
+class Finish(Namable):
     def __init__(self, duration, instant):
         self.duration = isinstance(duration, Duration) and \
                                 duration or Duration(duration)
@@ -218,10 +208,8 @@ class Finish(utils.Name):
     def put_action(self, vrs):
         return '(modify-instance %s (end %s))' % (self.duration.put(vrs), self.instant.put(vrs))
 
-utils.register('Finish', Finish)
 
-
-class During(utils.Name):
+class During(Namable):
     '''
     given an instant and a duration, build a condition for a rule
     that tests whether the instant is within the duration
@@ -239,10 +227,8 @@ class During(utils.Name):
             durs.append('(test (and (<= (send %(dur)s get-start) %(ins)s) (or (= (send %(dur)s get-end) -1) (>= (send %(dur)s get-end) %(ins)s))))' % {'dur': duration.put(vrs), 'ins': self.instant.put(vrs)})
         return ' '.join(durs)
 
-utils.register('During', During)
 
-
-class DurationOpMixin(utils.Name):
+class DurationOpMixin(Namable):
     '''
     Abstract ancestor of classes constructed with a sequence of durations
     '''
@@ -251,9 +237,6 @@ class DurationOpMixin(utils.Name):
           [isinstance(dur, Duration) and dur or Duration(dur) for dur in args]
 
 
-utils.register('DurationOpMixin', DurationOpMixin)
-
-
 class Coincide(DurationOpMixin):
     '''
     given a set of durations, build a condition for a rule
@@ -269,7 +252,6 @@ class Coincide(DurationOpMixin):
                 """ % {'durs': ' '.join([dur.put(vrs) for dur in self.durations])}
 
 
-utils.register('Coincide', Coincide)
 
 class Intersection(DurationOpMixin):
     '''
@@ -284,7 +266,6 @@ class Intersection(DurationOpMixin):
                                            (end (maxcomend %(durs)s)))
                 """ % {'durs': ' '.join([dur.put(vrs) for dur in self.durations])}
 
-utils.register('Intersection', Intersection)
 
 class MinComStart(DurationOpMixin):
     """
@@ -295,7 +276,6 @@ class MinComStart(DurationOpMixin):
         instants = [dur.put(vrs) for dur in self.durations]
         return '(mincomstart %s)' % ' '.join(instants)
 
-utils.register('MinComStart', MinComStart)
 
 class MaxComEnd(DurationOpMixin):
     """
@@ -306,4 +286,3 @@ class MaxComEnd(DurationOpMixin):
         instants = [dur.put(vrs) for dur in self.durations]
         return '(maxcomend %s)' % ' '.join(instants)
 
-utils.register('MaxComEnd', MaxComEnd)
